.. :changelog:

History
-------

0.1 (10.12.2012)
++++++++++++++++

* First release!
* Added Estonian banks:
  * Danske bank (IPizza)
  * Krediidipank (IPizza)
  * LHV pank  (IPizza)
  * Nordea (Solo/TUPAS)
  * SEB bank (IPizza)
  * Swedbank (IPizza)
